magneticalc.CalculationThread.CalculationThread

# ``magneticalc`.`CalculationThread`.`CalculationThread``

class documentation

`class CalculationThread(QThread):`

Constructor: `CalculationThread(gui)`

View In Hierarchy

CalculationThread class. The calculation thread implements an offloaded pipeline of subsequent calculation subtasks. The pipeline may be interrupted at (almost) any time, thereby exiting this thread.

Method | `__init__` | Initializes calculation thread.
Method | `disconnect_signals` | Disconnects all valid state signals
Method | `run` | Thread main function.
Instance Variable | `gui` | Undocumented
Method | `_on_finished` | Signals that the calculation finished.
Class Variable | `_field_valid` | Undocumented
Class Variable | `_metric_valid` | Undocumented
Class Variable | `_parameters_valid` | Undocumented
Class Variable | `_progress_update` | Undocumented
Class Variable | `_sampling_volume_valid` | Undocumented
Class Variable | `_wire_valid` | Undocumented

def __init__(self, gui: `GUI`):

Initializes calculation thread.

Parameters
gui: `GUI` | GUI

def disconnect_signals(self):

Disconnects all valid state signals

def run(self):

Thread main function.

gui =

Undocumented

def _on_finished(self, success: `bool`):

Signals that the calculation finished.

Parameters
success: `bool` | True if calculation was successful, False otherwise

_field_valid =

Undocumented

_metric_valid =

Undocumented

_parameters_valid =

Undocumented

_progress_update =

Undocumented

_sampling_volume_valid =

Undocumented

_wire_valid =

Undocumented